@@ -68,6 +68,16 @@ class MXAcquisition(Acquisition):
   _fluo_mapping_roi_params =\
     StrictOrderedDict([('id',None), ('start_energy',None), ('end_energy',None), ('element',None), ('edge',None), ('r',None), ('g',None), ('b',None)])
 
+  def upsert_xray_centring_result(self, result_id=None, grid_info_id=None,
+      method=None, status=None, x=None, y=None):
+    '''Insert or update the xray centring result associated with a grid info
+       :return: The xray centring result id.
+    '''
+    return self.get_connection().call_sp_write(
+        procname="upsert_xray_centring_result",
+        args=[ result_id, grid_info_id, method, status, x, y ],
+    )
+
   @classmethod
   def get_dc_position_params(cls):
     return copy.deepcopy(cls._dc_position_params)
@@ -84,13 +94,13 @@ class MXAcquisition(Acquisition):
     '''Insert or update the grid info associated with a data collection group'''
     return self.get_connection().call_sp_write('upsert_dcg_grid', values)
 
-  def retrieve_dcg_grid(self, dcgid):
+  def retrieve_dcg_grid(self, dcgid, auth_login=None):
     '''Retrieve a list of dictionaries containing the grid information for
        one data collection group id. Raises ISPyBNoResultException if there
        is no grid information available for the given DCGID.
        Generally the list will only contain a single dictionary.
     '''
-    return self.get_connection().call_sp_retrieve(procname='retrieve_grid_info_for_dcg', args=(dcgid,))
+    return self.get_connection().call_sp_retrieve(procname='retrieve_grid_info_for_dcg_v2', args=(dcgid, auth_login))
 
   @classmethod
   def get_energy_scan_params(cls):
