@@ -15,10 +15,6 @@ from ispyb.strictordereddict import StrictOrderedDict
 class MXProcessing(ispyb.interface.processing.IF):
   '''MXProcessing provides methods to store MX processing data.'''
 
-  _program_params = StrictOrderedDict([('id',None), ('cmd_line',None), ('programs',None),
-    ('status',None), ('message',None), ('starttime',None), ('updatetime',None), ('environment',None), ('processing_job_id',None),
-    ('recordtime',None)])
-
   _program_attachment_params = StrictOrderedDict([('id',None), ('parentid', None), ('file_name',None), ('file_path',None), ('file_type',None)])
 
   _processing_params = StrictOrderedDict([('id',None), ('parentid',None), ('spacegroup',None),
@@ -69,10 +65,6 @@ class MXProcessing(ispyb.interface.processing.IF):
   def get_run_blob_params(cls):
     return copy.deepcopy(cls._run_blob_params)
 
-  @classmethod
-  def get_program_params(cls):
-    return copy.deepcopy(cls._program_params)
-
   @classmethod
   def get_program_attachment_params(cls):
     return copy.deepcopy(cls._program_attachment_params)
@@ -119,10 +111,6 @@ class MXProcessing(ispyb.interface.processing.IF):
   def get_job_image_sweep_params(cls):
      return copy.deepcopy(cls._job_image_sweep_params)
 
-  def upsert_program(self, values):
-    '''Store new or update existing program params.'''
-    return self.get_connection().call_sp_write(procname='upsert_processing_program', args=values) # doesn't work with dict cursors
-
   def upsert_program_ex(self, program_id=None, job_id=None, name=None,
       command=None, environment=None, message=None, status=None,
       time_defined=None, time_start=None, time_update=None):
@@ -168,29 +156,35 @@ class MXProcessing(ispyb.interface.processing.IF):
     '''Update or insert new entry with info about views (image paths) for an MX molecular replacement run, e.g. Dimple.'''
     return self.get_connection().call_sp_write(procname='upsert_mrrun_blob', args=values)
 
-  def retrieve_job(self, id):
+  def retrieve_job(self, id, auth_login=None):
     '''Retrieve info about the processing job with id=id'''
-    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_job', args=(id,))
+    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_job_v2', args=(id, auth_login))
 
-  def retrieve_job_parameters(self, id):
+  def retrieve_job_parameters(self, id, auth_login=None):
     '''Retrieve info about the parameters for processing job with id=id'''
-    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_job_parameters', args=(id,))
+    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_job_parameters_v2', args=(id, auth_login))
 
-  def retrieve_job_image_sweeps(self, id):
+  def retrieve_job_image_sweeps(self, id, auth_login=None):
     '''Retrieve info about the image sweeps for job with id=id'''
-    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_job_image_sweeps', args=(id,))
+    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_job_image_sweeps_v2', args=(id, auth_login))
 
-  def retrieve_programs_for_job_id(self, id):
+  def retrieve_programs_for_job_id(self, id, auth_login=None):
     '''Retrieve the processing instances associated with the given processing job ID'''
-    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_programs_for_job_id', args=(id,))
+    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_programs_for_job_id_v2', args=(id, auth_login))
 
-  def retrieve_program_attachments_for_data_collection_group_and_program(self, id, program):
+  def retrieve_program_attachments_for_data_collection_group_and_program(self, id, program, auth_login=None):
     '''Retrieve the processing program attachments associated with the given data collection group and processing program'''
-    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_program_attachments_for_dc_group_and_program', args=(id,program))
+    return self.get_connection().call_sp_retrieve(
+      procname='retrieve_processing_program_attachments_for_dc_group_program_v2', 
+      args=(id, program, auth_login)
+    )
 
-  def retrieve_program_attachments_for_program_id(self, id):
+  def retrieve_program_attachments_for_program_id(self, id, auth_login=None):
     '''Retrieve the processing program attachments associated with the given processing program ID'''
-    return self.get_connection().call_sp_retrieve(procname='retrieve_processing_program_attachments_for_program_id', args=(id,))
+    return self.get_connection().call_sp_retrieve(
+      procname='retrieve_processing_program_attachments_for_program_id_v2', 
+      args=(id, auth_login)
+    )
 
   def upsert_job(self, values):
     '''Update or insert a new processing job entry'''
